@@ -6,6 +6,8 @@ pub mod alert_event_type_enum;
 pub use self::alert_event_type_enum::AlertEventTypeEnum;
 pub mod alert_request;
 pub use self::alert_request::AlertRequest;
+pub mod alpha_event_source;
+pub use self::alpha_event_source::AlphaEventSource;
 pub mod artifact_types_enum;
 pub use self::artifact_types_enum::ArtifactTypesEnum;
 pub mod callback_token_auth_request;
@@ -40,8 +42,6 @@ pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
 pub use self::error_detail::ErrorDetail;
-pub mod event_source_enum;
-pub use self::event_source_enum::EventSourceEnum;
 pub mod experiment;
 pub use self::experiment::Experiment;
 pub mod experiment_device_config;
@@ -56,6 +56,10 @@ pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
 pub use self::model_artifact::ModelArtifact;
+pub mod nested;
+pub use self::nested::Nested;
+pub mod nested_request;
+pub use self::nested_request::NestedRequest;
 pub mod octo_generic_event;
 pub use self::octo_generic_event::OctoGenericEvent;
 pub mod octo_job_event;
@@ -166,8 +170,6 @@ pub mod paginated_task_status_list;
 pub use self::paginated_task_status_list::PaginatedTaskStatusList;
 pub mod paginated_telemetry_event_polymorphic_list;
 pub use self::paginated_telemetry_event_polymorphic_list::PaginatedTelemetryEventPolymorphicList;
-pub mod paginated_user_list;
-pub use self::paginated_user_list::PaginatedUserList;
 pub mod partner3_d_geeks_alert;
 pub use self::partner3_d_geeks_alert::Partner3DGeeksAlert;
 pub mod partner3_d_geeks_metadata;
